@@ -20,19 +20,17 @@
 struct opd_header {
 	u8  magic[4];
 	u32 version;
-	u8 is_kernel;
+	u32 cpu_type;
 	u32 ctr_event;
 	u32 ctr_um;
-	/* ctr number, used for sanity checking */
-	u32 ctr;
-	u32 cpu_type;
 	u32 ctr_count;
+	// for cg file the from_cg_is_kernel
+	u32 is_kernel;
 	double cpu_speed;
 	time_t mtime;
-	int separate_lib_samples;
-	int separate_kernel_samples;
+	u32 cg_to_is_kernel;
 	/* binary compatibility reserve */
-	u32 reserved1[19];
+	u32 reserved1[5];
 };
 
 #endif /* OP_SAMPLE_FILE_H */
