@@ -30,9 +30,10 @@ namespace {
 // we should maintain the original to maintain the wordexp etc.
 string const fixup_image_spec(string const & str, extra_images const & extra)
 {
+	string dummy_archive_path;
 	// FIXME: what todo if an error in find_image_path() ?
 	image_error error;
-	return find_image_path(str, extra, error);
+	return find_image_path(dummy_archive_path, str, extra, error);
 }
 
 
@@ -50,13 +51,9 @@ void fixup_image_spec(vector<string> & images, extra_images const & extra)
 
 
 profile_spec::profile_spec(extra_images const & extra)
-	:
-	normal_tag_set(false),
-	sample_file_set(false),
-	extra(extra)
+	: extra(extra)
 {
-	parse_table["sample-file"] = &profile_spec::parse_sample_file;
-	parse_table["binary"] = &profile_spec::parse_binary;
+	parse_table["archive"] = &profile_spec::parse_archive_path;
 	parse_table["session"] = &profile_spec::parse_session;
 	parse_table["session-exclude"] =
 		&profile_spec::parse_session_exclude;
@@ -92,65 +89,40 @@ bool profile_spec::is_valid_tag(string const & tag_value)
 }
 
 
-void profile_spec::validate()
-{
-	// 3.3 sample_file can be used only with binary
-	// 3.4 binary can be used only with sample_file
-	if (normal_tag_set && (sample_file_set || !binary.empty())) {
-		throw invalid_argument("Cannot specify sample-file: or "
-			"binary: tag with another tag or binary name");
-	}
-
-	// PP:3.5 no session given means use the current session.
-	if (session.empty()) {
-		session.push_back("current");
-	}
-
-	// PP:3.7 3.8 3.9 3.10: is it the right time to translate all filename
-	// to absolute path ? (if yes do it after plugging this code in
-	// oprofile)
-}
-
-
 void profile_spec::set_image_or_lib_name(string const & str)
 {
-	normal_tag_set = true;
 	/* FIXME: what does spec say about this being allowed to be
 	 * a comma list or not ? */
 	image_or_lib_image.push_back(fixup_image_spec(str, extra));
 }
 
 
-void profile_spec::parse_sample_file(string const & str)
+void profile_spec::parse_archive_path(string const & str)
 {
-	sample_file_set = true;
-	file_spec.set_sample_filename(str);
+	archive_path = op_realpath(str);
 }
 
 
-void profile_spec::parse_binary(string const & str)
+string profile_spec::get_archive_path() const
 {
-	binary = str;
+	return archive_path;
 }
 
 
 void profile_spec::parse_session(string const & str)
 {
-	normal_tag_set = true;
 	session = separate_token(str, ',');
 }
 
 
 void profile_spec::parse_session_exclude(string const & str)
 {
-	normal_tag_set = true;
 	session_exclude = separate_token(str, ',');
 }
 
 
 void profile_spec::parse_image(string const & str)
 {
-	normal_tag_set = true;
 	image = separate_token(str, ',');
 	fixup_image_spec(image, extra);
 }
@@ -158,14 +130,12 @@ void profile_spec::parse_image(string const & str)
 
 void profile_spec::parse_image_exclude(string const & str)
 {
-	normal_tag_set = true;
 	image_exclude = separate_token(str, ',');
 }
 
 
 void profile_spec::parse_lib_image(string const & str)
 {
-	normal_tag_set = true;
 	lib_image = separate_token(str, ',');
 	fixup_image_spec(image, extra);
 }
@@ -173,42 +143,36 @@ void profile_spec::parse_lib_image(string const & str)
 
 void profile_spec::parse_event(string const & str)
 {
-	normal_tag_set = true;
 	event.set(str);
 }
 
 
 void profile_spec::parse_count(string const & str)
 {
-	normal_tag_set = true;
 	count.set(str);
 }
 
 
 void profile_spec::parse_unitmask(string const & str)
 {
-	normal_tag_set = true;
 	unitmask.set(str);
 }
 
 
 void profile_spec::parse_tid(string const & str)
 {
-	normal_tag_set = true;
 	tid.set(str);
 }
 
 
 void profile_spec::parse_tgid(string const & str)
 {
-	normal_tag_set = true;
 	tgid.set(str);
 }
 
 
 void profile_spec::parse_cpu(string const & str)
 {
-	normal_tag_set = true;
 	cpu.set(str);
 }
 
@@ -258,11 +222,6 @@ bool comma_match(comma_list<T> const & cl, generic_spec<T> const & value)
 
 bool profile_spec::match(filename_spec const & spec) const
 {
-	// PP:3.3 if spec was defined through sample-file: match it directly
-	if (sample_file_set) {
-		return file_spec.match(spec, binary);
-	}
-
 	bool matched_by_image_or_lib_image = false;
 
 	// PP:3.19
@@ -360,7 +319,10 @@ profile_spec profile_spec::create(vector<string> const & args,
 		}
 	}
 
-	spec.validate();
+	// PP:3.5 no session given means use the current session.
+	if (spec.session.empty()) {
+		spec.session.push_back("current");
+	}
 
 	return spec;
 }
@@ -440,7 +402,7 @@ list<string> profile_spec::generate_file_list(bool exclude_dependent,
 
 		string base_dir;
 		if ((*cit)[0] != '.' && (*cit)[0] != '/')
-			base_dir = OP_SAMPLES_DIR;
+			base_dir = archive_path + OP_SAMPLES_DIR;
 		base_dir += *cit;
 
 		base_dir = op_realpath(base_dir);
