@@ -18,18 +18,40 @@ extern "C" {
 
 #include <sys/types.h>
 
+/**
+ * op_file_readable - is a file readable
+ * @param file file name
+ *
+ * Return true if the given file is readable.
+ *
+ * Beware of race conditions !
+ */
 int op_file_readable(char const * file);
+
+/**
+ * op_get_fsize - get size of file
+ * @param file file name
+ * @param size size parameter to fill
+ *
+ * Returns the size of the named file in bytes
+ * into the pointer given. Returns non-zero
+ * on failure, in which case size is not changed.
+ */
 int op_get_fsize(char const * file, off_t * size);
+
+/**
+ * op_get_mtime - get mtime of file
+ * @param file  file name
+ *
+ * Returns the mtime of the given file or 0 on failure
+ */
 time_t op_get_mtime(char const * file);
-char * op_relative_to_absolute_path(
-	char const * path, char const * base_dir);
 
 /**
  * create_dir - create a directory
  * @param dir  the directory name to create
  *
- * return false if the directory dir does not exist
- * and cannot be created
+ * Returns 0 on success.
  */
 int create_dir(char const * dir);
 
@@ -39,7 +61,10 @@ int create_dir(char const * dir);
  * @param path  the path to create
  *
  * create directory for each dir components in path
- * return false if one of the path cannot be created.
+ * the last path component is not considered as a directory
+ * but as a filename
+ *
+ * Returns 0 on success.
  */
 int create_path(char const * path);
 
